# Table of Contents

- [notifications](<./notifications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Notifications](<./Notifications.md>)
  - [Overview](<./Notifications/Overview.md>)
  - [Notification Channels](<./Notifications/Notification-Channels.md>)
  - [Setting Your Notification Preferences](<./Notifications/Setting-Your-Notification-Preferences.md>)
  - [Was this page helpful?](<./Notifications/Was-this-page-helpful.md>)
